@@ -2025,3 +2025,12 @@ class VariableClBuilderBootParams(Variable):
     Параметры загрузки ядра в собираемом образе и boot live
     """
     value = ""
+
+
+class VariableClCheckUpdateLevel(Variable):
+    """
+    Проверять уровень обновления 
+    при соединении с binhost
+    """
+    type = "bool"
+    value = "off"
\ No newline at end of file
